@@ -46,8 +46,10 @@ class CrisprShrinkageVisualizationInput:
     negative_control_count_rep: List[List[Union[int, float]]]
     explanatory_count_rep: List[List[Union[int, float]]]
 
+    
 
-def prepare_crispr_shrinkage_visualization_input(crispr_shrinkage_result: CrisprShrinkageResult):
+
+def prepare_crispr_shrinkage_visualization_input(crispr_shrinkage_result: CrisprShrinkageResult, use_rescaled: bool = True):
     replicate_indices = range(crispr_shrinkage_result.num_replicates)
     explanatory_guides = [guide for guide in np.concatenate([crispr_shrinkage_result.adjusted_observation_guides, crispr_shrinkage_result.adjusted_positive_control_guides, crispr_shrinkage_result.adjusted_negative_control_guides]) if guide.is_explanatory is True]
     
@@ -59,20 +61,38 @@ def prepare_crispr_shrinkage_visualization_input(crispr_shrinkage_result: Crispr
     negative_positions = np.asarray([guide.position for guide in crispr_shrinkage_result.adjusted_positive_control_guides])
     explanatory_positions =  np.asarray([guide.position for guide in explanatory_guides])
 
-    negative_lfc = np.asarray([guide.LFC_estimate_combined_rescaled for guide in crispr_shrinkage_result.adjusted_negative_control_guides])
-    positive_lfc = np.asarray([guide.LFC_estimate_combined_rescaled for guide in crispr_shrinkage_result.adjusted_positive_control_guides])
-    observational_lfc = np.asarray([guide.LFC_estimate_combined_rescaled for guide in crispr_shrinkage_result.adjusted_observation_guides])
-    explanatory_lfc = np.asarray([guide.LFC_estimate_combined_rescaled for guide in explanatory_guides])
+    if use_rescaled:
+        negative_lfc = np.asarray([guide.LFC_estimate_combined_rescaled for guide in crispr_shrinkage_result.adjusted_negative_control_guides])
+        positive_lfc = np.asarray([guide.LFC_estimate_combined_rescaled for guide in crispr_shrinkage_result.adjusted_positive_control_guides])
+        observational_lfc = np.asarray([guide.LFC_estimate_combined_rescaled for guide in crispr_shrinkage_result.adjusted_observation_guides])
+        explanatory_lfc = np.asarray([guide.LFC_estimate_combined_rescaled for guide in explanatory_guides])
+    else:
+        negative_lfc = np.asarray([guide.LFC_estimate_combined for guide in crispr_shrinkage_result.adjusted_negative_control_guides])
+        positive_lfc = np.asarray([guide.LFC_estimate_combined for guide in crispr_shrinkage_result.adjusted_positive_control_guides])
+        observational_lfc = np.asarray([guide.LFC_estimate_combined for guide in crispr_shrinkage_result.adjusted_observation_guides])
+        explanatory_lfc = np.asarray([guide.LFC_estimate_combined for guide in explanatory_guides])
 
-    observational_lfc_CI = [guide.LFC_estimate_combined_CI_rescaled for guide in crispr_shrinkage_result.adjusted_observation_guides]
-    positive_control_lfc_CI = [guide.LFC_estimate_combined_CI_rescaled for guide in crispr_shrinkage_result.adjusted_positive_control_guides]
-    negative_control_lfc_CI = [guide.LFC_estimate_combined_CI_rescaled for guide in crispr_shrinkage_result.adjusted_negative_control_guides]
-    explanatory_lfc_CI =  [guide.LFC_estimate_combined_CI_rescaled for guide in explanatory_guides]
+    if use_rescaled:
+        observational_lfc_CI = [guide.LFC_estimate_combined_CI_rescaled for guide in crispr_shrinkage_result.adjusted_observation_guides]
+        positive_control_lfc_CI = [guide.LFC_estimate_combined_CI_rescaled for guide in crispr_shrinkage_result.adjusted_positive_control_guides]
+        negative_control_lfc_CI = [guide.LFC_estimate_combined_CI_rescaled for guide in crispr_shrinkage_result.adjusted_negative_control_guides]
+        explanatory_lfc_CI =  [guide.LFC_estimate_combined_CI_rescaled for guide in explanatory_guides]
+    else:
+        observational_lfc_CI = [guide.LFC_estimate_combined_CI for guide in crispr_shrinkage_result.adjusted_observation_guides]
+        positive_control_lfc_CI = [guide.LFC_estimate_combined_CI for guide in crispr_shrinkage_result.adjusted_positive_control_guides]
+        negative_control_lfc_CI = [guide.LFC_estimate_combined_CI for guide in crispr_shrinkage_result.adjusted_negative_control_guides]
+        explanatory_lfc_CI =  [guide.LFC_estimate_combined_CI for guide in explanatory_guides]
 
-    observational_lfc_rep = np.asarray([[guide.LFC_estimate_per_replicate_rescaled[rep_i] for guide in crispr_shrinkage_result.adjusted_observation_guides] for rep_i in replicate_indices])
-    negative_lfc_rep = np.asarray([[guide.LFC_estimate_per_replicate_rescaled[rep_i] for guide in crispr_shrinkage_result.adjusted_negative_control_guides] for rep_i in replicate_indices])
-    positive_lfc_rep = np.asarray([[guide.LFC_estimate_per_replicate_rescaled[rep_i] for guide in crispr_shrinkage_result.adjusted_positive_control_guides] for rep_i in replicate_indices])
-    explanatory_lfc_rep = np.asarray([[guide.LFC_estimate_per_replicate_rescaled[rep_i] for guide in explanatory_guides] for rep_i in replicate_indices])
+    if use_rescaled:
+        observational_lfc_rep = np.asarray([[guide.LFC_estimate_per_replicate_rescaled[rep_i] for guide in crispr_shrinkage_result.adjusted_observation_guides] for rep_i in replicate_indices])
+        negative_lfc_rep = np.asarray([[guide.LFC_estimate_per_replicate_rescaled[rep_i] for guide in crispr_shrinkage_result.adjusted_negative_control_guides] for rep_i in replicate_indices])
+        positive_lfc_rep = np.asarray([[guide.LFC_estimate_per_replicate_rescaled[rep_i] for guide in crispr_shrinkage_result.adjusted_positive_control_guides] for rep_i in replicate_indices])
+        explanatory_lfc_rep = np.asarray([[guide.LFC_estimate_per_replicate_rescaled[rep_i] for guide in explanatory_guides] for rep_i in replicate_indices])
+    else:
+        observational_lfc_rep = np.asarray([[guide.LFC_estimate_per_replicate[rep_i] for guide in crispr_shrinkage_result.adjusted_observation_guides] for rep_i in replicate_indices])
+        negative_lfc_rep = np.asarray([[guide.LFC_estimate_per_replicate[rep_i] for guide in crispr_shrinkage_result.adjusted_negative_control_guides] for rep_i in replicate_indices])
+        positive_lfc_rep = np.asarray([[guide.LFC_estimate_per_replicate[rep_i] for guide in crispr_shrinkage_result.adjusted_positive_control_guides] for rep_i in replicate_indices])
+        explanatory_lfc_rep = np.asarray([[guide.LFC_estimate_per_replicate[rep_i] for guide in explanatory_guides] for rep_i in replicate_indices])
 
     sample_population_negative_control_total_normalized_count = np.asarray([guide.sample_population_normalized_count_reps for guide in crispr_shrinkage_result.adjusted_negative_control_guides]).sum(axis=0)
     control_population_negative_control_total_normalized_count = np.asarray([guide.control_population_normalized_count_reps for guide in crispr_shrinkage_result.adjusted_negative_control_guides]).sum(axis=0)
